@@ -229,9 +229,9 @@ class SqlAlchemyProxy:
     def getConnectArgs(self, connectArgs) :
         if ObjectHelper.isNone(connectArgs) :
             connectArgs = self.globals.getSetting(f'{self.KW_API}{c.DOT}{self.KW_DATABASE}{c.DOT}{self.KW_REPOSITORY_SETTINGS}')
-            finalConnectArgs = {}
+            finalConnectArgs = None
             if ObjectHelper.isDictionary(connectArgs) :
-                finalConnectArgs = connectArgs.get(SettingHelper.getActiveEnvironment())
+                finalConnectArgs = connectArgs.get(SettingHelper.getActiveEnvironment(), None)
             return finalConnectArgs
         else :
             return connectArgs
